<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Consultor extends CI_Controller {

	public function __construct()
	{
		parent::__construct();
		$this->load->helper('form');
		$this->load->helper('url');
		$this->load->library('form_validation');
		$this->load->library('session');
		$this->load->library('pagination');
		$this->load->model('consultor_model');
		$this->load->model('contenido_model');
		$this->load->model('clientes_model');
		$this->load->model('consultas_model');
		$this->load->model('citas_model');
	}

	public function index(){
		$this->validar_sesion();
		redirect('consultor/inicio');
	}

	public function inicio()
	{
		redirect('consultor/contenido-legal/principal');
	}

	public function login(){
		$this->load_header('login', array(), 'Acceso');
		$this->load->view('login');
		$this->load->view('templates/footer');
	}

	public function logout(){
		$this->session->sess_destroy();
		redirect('consultor/login');
	}
	
	public function citas($page='calendario', $idcita='')
	{
		// $this->validar_sesion();

		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);

		switch ($page) {
			default:
			case 'calendario':
				$data['page_scripts'] = array('underscore-min.js', 'calendar.min.js', 'citas.js');

				$this->load_header('citas', $data, 'Calendario de citas');
				$this->load->view('abogado/citas/calendario', $data);
				$this->load->view('templates/footer', $data);
				break;
			case 'ver-cita':

				break;
			case 'nueva-cita':
				break;
		}
	}

	public function expediente($page='casos')
	{
		$this->validar_sesion();

		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);

		switch ($page) {
			default:
			// redirect('consultor/expediente/casos');
			// break;
			case 'casos':
				$view_name = 'abogado/expediente/expediente-casos';
				$page_title = 'Lista de casos';
				$order_by = ($this->is_null_or_empty_string($this->uri->segment(4))) ? 'por-fecha' : $this->uri->segment(4);
				$order_mode = ($this->is_null_or_empty_string($this->uri->segment(5))) ? 'desc' : $this->uri->segment(5);

				// Paginación
				$config = $this->pagination_config();
				$config['base_url'] = site_url('consultor/expediente');
				$config['total_rows'] = $this->consultas_model->lista_casos_count();
				$config['per_page'] = "5";
				$config["uri_segment"] = 3;
				$choice = $config["total_rows"] / $config["per_page"];
				$config["num_links"] = floor($choice);
				$data['page'] = ($this->uri->segment(3)) ? $this->uri->segment(3) : 0;
				$this->pagination->initialize($config);
				$data['pagination'] = $this->pagination->create_links();

				$data['listado_casos'] = $this->consultas_model->lista_casos('' ,$order_by, $order_mode, $data['page'], $config["per_page"]);
				$data['order_mode'] = $order_mode;
				$data['order_by'] = $order_by;
				$data['page_scripts'] = array('bootbox.min.js', 'moment-with-locales.min.js', 'bootstrap-datetimepicker.min.js','jquery.autocomplete.min.js', 'expediente.js');

				break;


		}

		$this->load_header('expediente', $data, $page_title);
		$this->load->view($view_name, $data);
		$this->load->view('templates/footer', $data);
	}

	public function consultas($page='', $consulta=10000){
		$this->validar_sesion();

		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);

		switch ($page) {
			default:
			case 'principal':
				redirect('consultor/consultas/lista');
			break;
			case 'lista':
				$view_name = 'abogado/consulta/consulta-lista';
				$page_title = 'Pendientes por responder';

				// Ordenación
				$order_by = ($this->is_null_or_empty_string($this->uri->segment(5))) ? 'por-fecha' : $this->uri->segment(5);
				$order_mode = ($this->is_null_or_empty_string($this->uri->segment(6))) ? 'desc' : $this->uri->segment(6);
				$data['order_mode'] = $order_mode;
				$data['order_by'] = $order_by;

				// Paginación
				$config = $this->pagination_config();
				$config['base_url'] = site_url('consultor/consultas/lista');
				$config['total_rows'] = $this->consultas_model->lista_consultas_count();
				$config['per_page'] = "5";
				$config["uri_segment"] = 4;
				$choice = $config["total_rows"] / $config["per_page"];
				$config["num_links"] = floor($choice);
				$data['page'] = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;
				$this->pagination->initialize($config);
				$data['pagination'] = $this->pagination->create_links();

				$idabogado = $this->session->userdata('consultor_idabogado');
				$data['listado_consultas'] = $this->consultas_model->lista_consultas($data['page'], $config["per_page"], $order_by, $order_mode);
				$data['categorias'] = $this->contenido_model->get_categorias_array();
				$data['page_scripts'] = array('moment-with-locales.min.js', 'bootstrap-datetimepicker.min.js','jquery.autocomplete.min.js', 'consultas.js','ajax.js');
				break;
			case 'responder':
				$data['categorias'] = $this->contenido_model->get_categorias_array();
				$data['consulta'] = $this->consultas_model->consulta($consulta)[0];
				$page_title = 'Responder consulta #'.$consulta;
				$view_name = 'abogado/consulta/consulta-responder';
				$data['page_scripts'] = array('bootbox.min.js', 'busqueda.js');
				break;
		}

		$this->load_header('consultas', $data, $page_title);
		$this->load->view($view_name, $data);
		$this->load->view('templates/footer', $data);
	}

	public function contenido_legal($page = 'principal'){
		$this->validar_sesion();

		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);

		switch ($page) {
			case 'principal':
			$view_name = 'abogado/contenido/contenido-bienvenida';
			$page_title = 'Principal';
			break;
			case 'carga':
			$view_name = 'abogado/contenido/contenido-carga';
			$page_title = 'Carga de contenido';
			$data['page_scripts'] = array('carga.js');
			break;
			case 'carga-excel':
			$view_name = 'abogado/contenido/contenido-carga-e';
			$page_title = 'Carga de contenido por excel';
			$data['page_scripts'] = array('carga-e.js');
			break;
			case 'revision':
			$view_name = 'abogado/contenido/contenido-revision';
			$page_title = 'Revisión de contenido';
			$data['page_scripts'] = array('bootbox.min.js', 'revision.js');

			$categorias = $this->contenido_model->get_categorias_array();
			$data['categorias'] = $categorias;

			$config = $this->pagination_config();
			$config['base_url'] = site_url('consultor/contenido-legal/revision');
			$config['total_rows'] = $this->db->count_all('textos');
			$config['per_page'] = "10";
			$config["uri_segment"] = 4;
			$choice = $config["total_rows"] / $config["per_page"];
			$config["num_links"] = floor($choice);

			$this->pagination->initialize($config);
			$data['page'] = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;
			$data['listing'] = $this->contenido_model->listado_informacion($data['page'], $config["per_page"]);
			$data['pagination'] = $this->pagination->create_links();
			break;
		}

		$this->load_header('contenido', $data, $page_title);
		$this->load->view($view_name, $data);
		$this->load->view('templates/footer', $data);
	}

	public function clientes($page='principal'){
		$this->validar_sesion();

		$data = array('consultor_nombres' => $this->session->userdata('consultor_nombres'));

		switch ($page) {
			default:
			case 'principal':
			$view_name = 'abogado/clientes/clientes-bienvenida';
			$page_title = 'Lista de clientes';
			break;
			case 'listado':
			$view_name = 'abogado/clientes/clientes-lista';
			$page_title = 'Lista de clientes';
			$data['page_scripts'] = array('ajax.js', 'editarcliente.js');

			$config = $this->pagination_config();
			$config['base_url'] = site_url('consultor/clientes/listado');
			$config['total_rows'] = $this->db->count_all('clientes');
			$config['per_page'] = "10";
			$config["uri_segment"] = 4;
			$choice = $config["total_rows"] / $config["per_page"];
			$config["num_links"] = floor($choice);

			$this->pagination->initialize($config);
			$data['page'] = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;

			$data['listado_clientes'] = $this->clientes_model->listado_clientes($data['page'], $config["per_page"]);
			$data['pagination'] = $this->pagination->create_links();
			break;
			case 'nuevo-cliente':
			$view_name = 'abogado/clientes/clientes-nuevo';
			$page_title = 'Nuevo cliente';
			$data['page_scripts'] = array('ajax.js');
			break;				
		}

		$this->load_header('clientes', $data, $page_title);
		$this->load->view($view_name, $data);
		$this->load->view('templates/footer', $data);
	}

	public function test($idtexto = '10000'){
		$query = $this->contenido_model->get_texto_from_db($idtexto);
		$texto = $query->result()[0];

		$contenido = $texto->contenido;

		$array = array();

		preg_match_all('/.+/',$contenido, $array);

		$lineas = $array[0];

		foreach ($lineas as $key => $linea) {
			// if (strlen(trim($linea)) < 1){
			// 	unset($lineas[$key]);
			// }
		}

		print "<pre>";
		echo print_r($lineas);
		print "</pre>";
	}

	/*********************************************************************************

								Funciones del login

	*********************************************************************************/

	function validar_sesion(){
		if($this->session->userdata('LOGGEDIN') === TRUE)
			return TRUE;
		else
			redirect('consultor/login');
	}

	function validar_login($login_query){
		$count = $login_query['rowcount'];
		$query = $login_query['query'];


		if ($count === 1) {
			$row = $query->row();

			$datos_consultor = array(
				'consultor_idabogado' => $row->idabogado,
				'consultor_nombres' => $row->nombres,
				'consultor_apellidop' => $row->apellidop,
				'consultor_apellidom' => $row->apellidom,
				'consultor_rfc' => $row->rfc,
				'consultor_cedula' => $row->cedula,
				'consultor_especialidad' => $row->especialidad,
				'LOGGEDIN' => TRUE
				);

			$this->session->set_userdata($datos_consultor);
			return TRUE;
		} else {
			return FALSE;
		}		
	}

	public function login_form(){
		$this->form_validation->set_rules('email', 'Usuario', 'trim|required|valid_email');
		$this->form_validation->set_rules('password', 'Contraseña', 'trim|required');

		if($this->form_validation->run() === FALSE){
			$this->session->set_flashdata($system_msg = array('type' => 'danger', 
				'msg' => validation_errors()));
			redirect('consultor/login');
		} else {

			$login_query = $this->consultor_model->login();

			if ($this->validar_login($login_query) === TRUE) {
				redirect('consultor/inicio');
			} else {
				$this->session->set_flashdata($system_msg = array('type' => 'warning', 
					'msg' => 'Verifique los datos e intente de nuevo'));
				redirect('consultor/login');
			}
		}
	}

	/*********************************************************************************

								Funciones de Clientes

	*********************************************************************************/

	public function addcliente_form(){
		$insert_result = $this->clientes_model->nuevo_cliente();

		if ($insert_result) {
			$this->session->set_flashdata($system_msg = array('type' => 'success', 
				'msg' => 'Se agregó correctamente el nuevo cliente'));
		} else {
			$this->session->set_flashdata($system_msg = array('type' => 'warning', 
				'msg' => 'Verifique los datos e intente de nuevo'));
		}

		redirect('consultor/clientes/nuevo-cliente');
	}

	public function editarcliente_form(){
		echo $this->clientes_model->editar_cliente();
	}

	public function eliminarcliente_form(){
		$id=$_POST['idcliente'];
		/*foreach ($id as $key => $value) {
			$idcliente[$key]=$value['value'];
		}*/

		//die('<pre>'.print_r($id,1).'</pre>');
		 $query= $this->clientes_model->eliminar_cliente($id);
		//redirect('consultor/clientes/listado');
		
		//echo json_encode($query);
	}

	function get_cliente_data(){
		echo json_encode($this->clientes_model->get_cliente());
	}

	public function cliente_autocomplete()
	{
		$query = $this->input->get('query');
		$result = $this->clientes_model->buscar_cliente($query);

		$suggestions = array();

		foreach ($result as $cliente) {
			$nombre_cliente = $cliente->apellidop.' '.$cliente->apellidom.', '.$cliente->nombres;
			$suggestions[] = array('data' => $cliente->idcliente, 'value' => $nombre_cliente);
		}

		$test = array('suggestions' => $suggestions);
		echo json_encode($test);
	}

	/*********************************************************************************

							Funciones de Carga de información

	*********************************************************************************/

	public function carga_form(){
		$this->form_validation->set_rules('nombre'	, 'Nombre'	, 'trim|required');
		$this->form_validation->set_rules('codigo'	, 'Código'	, 'trim|required|numeric');
		$this->form_validation->set_rules('materia'	, 'Materia'	, 'trim|required|numeric');
		$this->form_validation->set_rules('tema'	, 'Tema'	, 'trim|required|numeric');
		$this->form_validation->set_rules('subtema'	, 'Subtema'	, 'trim|required|numeric');
		$this->form_validation->set_rules('contenido', 'Contenido', 'trim|required');

		if($this->form_validation->run() === FALSE){
			$this->session->set_flashdata($system_msg = array('type' => 'warning', 
				'msg' => 'Verifique los datos e intente de nuevo'));
		} else {
			if($this->contenido_model->carga_informacion($this->session->userdata('consultor_idabogado'))){
				$this->session->set_flashdata($system_msg = array('type' => 'success', 
					'msg' => 'Se ha cargado correctamente la información'));
			} else {
				$this->session->set_flashdata($system_msg = array('type' => 'danger', 
					'msg' => 'No se pudo guardar la información. Contacte al administrador del sistema'));
			}
		}
		redirect('consultor/contenido-legal/carga');
	}

	public function carga_excel(){
		$idabogado = $this->session->userdata('consultor_idabogado');
		$esjurisprudencia = $this->input->post('esjurisprudencia', TRUE);

		$config['upload_path'] = './carga/';
		$config['allowed_types'] = 'xlsx';
		$config['file_name'] = 'carga_'.$idabogado.'_'.time().'.xlsx';

		$this->load->library('upload', $config);
		$this->session->excelfile = NULL;

		if ( ! $this->upload->do_upload('excelfile')){
			$error = array('error' => $this->upload->display_errors());
			echo json_encode($error);
		} else {
			$data = array('upload_data' => $this->upload->data());
			$this->load->library('PHPExcel');

			$file = $data['upload_data']['full_path'];

			$phpexcel = PHPExcel_IOFactory::load($file);

			if ($phpexcel->sheetNameExists('Jurisprudencias') && $phpexcel->sheetNameExists('Articulos')) {
				if ($esjurisprudencia) {
					$articulos = $phpexcel->getSheetByName('Jurisprudencias');	
				} else {
					$articulos = $phpexcel->getSheetByName('Articulos');
				}

				$start_row = 2; // Iniciar desde fila 2 para evitar encabezado en fila 1
				// En PHPExcel las filas empiezan de 1 y las columnas de 0
				// Raro... ಠ_ಠ    ಠ_ಠ    ಠ_ಠ    ಠ_ಠ    ಠ_ಠ    ಠ_ಠ    ಠ_ಠ

				$data['invalid_rows'] = array();
				$data['rowcount'] = 0;
				$data['valid_rows'] = 0;

				for ($row = $start_row; $row <= $articulos->getHighestRow() ; $row++) {
					if(!is_null($articulos->getCellByColumnAndRow(0, $row)->getValue())){
						if(!is_null($articulos->getCellByColumnAndRow(1, $row)->getValue())){
							if(!is_null($articulos->getCellByColumnAndRow(2, $row)->getValue())){
								$data['valid_rows']++;
							} else {
								$data['invalid_rows'][] = array('row' => $row, 'reason' => 'Falta contenido');
							}
						} else {
							$data['invalid_rows'][] = array('row' => $row, 'reason' => 'Falta artículo');
						}
					} else {
						$data['invalid_rows'][] = array('row' => $row, 'reason' => 'Falta código');
					}

					$data['rowcount']++;

				// $data['leyes'][$row] = array(
				// 	'codigo' => $articulos->getCellByColumnAndRow(0, $row)->getValue(),
				// 	'articulo' => $articulos->getCellByColumnAndRow(1, $row)->getValue(),
				// 	'contenido' => $articulos->getCellByColumnAndRow(2, $row)->getValue()
				// 	);
				}

				$data['HighestRow'] = $articulos->getHighestRow();

				$this->session->excelfile = $data['upload_data']['full_path'];

				echo json_encode($data);
			} else {
				$error = array('error' => 'El archivo no cuenta con el formato requerido. Use la plantilla porporcionada');
				echo json_encode($error);
			}
		}
	}

	public function code_test($codigo = 'L/TM-1-2-3')
	{
		$this->load->library('ATACode');

		//$atacode = new ATACode();

		$code = $this->atacode->parse_code($codigo);

		$this->contenido_model->codigo_a_ids($code);

		echo '<pre>'.json_encode($code->code_debug(), JSON_PRETTY_PRINT).'</pre>';
	}

	public function procesa_excel($value='')
	{
		$idcodigo = $this->input->post('codigo');
		$esjurisprudencia = $this->input->post('esjurisprudencia', TRUE);
		$excelfile = $this->session->userdata('excelfile');
		$shortcode = FALSE;

		if(!is_null($excelfile)){
			$this->load->library('PHPExcel');
			$this->load->library('ATACode');

			$phpexcel = PHPExcel_IOFactory::load($excelfile);
			if ($esjurisprudencia) {
					$articulos = $phpexcel->getSheetByName('Jurisprudencias');
					$shortcode = TRUE;
				} else {
					$articulos = $phpexcel->getSheetByName('Articulos');
				}

			$start_row = 2;

			$leyes = array();

			for ($row = $start_row; $row <= $articulos->getHighestRow() ; $row++) {
				if(!is_null($articulos->getCellByColumnAndRow(0, $row)->getValue())){
					if(!is_null($articulos->getCellByColumnAndRow(1, $row)->getValue())){
						if(!is_null($articulos->getCellByColumnAndRow(2, $row)->getValue())){
							$codigo_ata = $articulos->getCellByColumnAndRow(0, $row)->getValue();
							
							$materia = $this->atacode->parse_code($codigo_ata, $shortcode)->getMateria();
							$tema = $this->atacode->parse_code($codigo_ata, $shortcode)->getTema();
							$subtema = $this->atacode->parse_code($codigo_ata, $shortcode)->getSubtemas(TRUE);

							$leyes[] = array(
								'idcodigo' => $idcodigo,
								'idmateria' => $materia['id'],
								'idtema' => $tema['id'],
								'idsubtema' => ($shortcode) ? -1 : $subtema['id'],
								'titulo' => $articulos->getCellByColumnAndRow(1, $row)->getValue(),
								'contenido' => $articulos->getCellByColumnAndRow(2, $row)->getValue(),
								/*'ultimaedicion' => time(),*/
								'idabogado' => $this->session->userdata('consultor_idabogado')
								);
						}
					}
				}
			}

			if (sizeof($leyes)) {
				$result = $this->contenido_model->carga_batch($leyes);
				if ($result === FALSE) {
					echo json_encode(array('status' => 'error', 'desc' => 'Ocurrió un error al cargar la información' ));
				} else {
					echo json_encode(array('status' => 'ok', 'desc' => 'La información se cargó correctamente', 'cargados' => $result));
				}
			} else {
				echo json_encode(array('status' => 'error', 'desc' => 'El archivo no contiene información válida' ));
			}
				
		} else {
			echo json_encode(array('status' => 'error', 'desc' => 'El archivo no existe' ));
		}
	}

	public function elimina_informacion(){
		echo $this->contenido_model->elimina_informacion();
	}

	public function busqueda_form(){

		$materia = $this->input->post('materia');
		$tema = $this->input->post('tema');
		$subtema = $this->input->post('subtema');

		$palabras = array(
			$this->input->post('pal1'),
			$this->input->post('pal2'), 
			$this->input->post('pal3'));

		$operadores = array(
			$this->input->post('op1'),
			$this->input->post('op2'), 
			$this->input->post('op3'));

		$categorias = $this->contenido_model->get_categorias_array();

		$codigos = $categorias['codigos'];
		$estados = $categorias['estados'];

		$articulos = $this->contenido_model->busca_informacion($materia, $tema, $subtema, $palabras, $operadores);

		$resultado = array();

		foreach ($articulos as $key => $articulo) {
			$contenido = $articulo->contenido;
			$parrafos = array();
			preg_match_all('/.+/',$contenido, $parrafos);
			$parrafos = $parrafos[0];

			foreach ($parrafos as $key => $parrafo) {
				$pal1_encontrado = stripos($parrafo, $palabras[0]);

				if(	!$this->is_null_or_empty_string($palabras[1])){
					$pal2_encontrado = stripos($parrafo, $palabras[1]);
					if($pal2_encontrado === FALSE && $operadores[1] == 'and'){
						continue;
					}

					if ($pal2_encontrado !== FALSE && $operadores[1] == 'not') {
						continue;
					}
				}

				if(	!$this->is_null_or_empty_string($palabras[2])){
					$pal3_encontrado = stripos($parrafo, $palabras[2]);
					if(($pal2_encontrado === FALSE || $pal3_encontrado === FALSE) && $operadores[2] == 'and'){
						continue;
					}

					if ($pal3_encontrado !== FALSE && $operadores[2] == 'not') {
						continue;
					}
				}

				if ($pal1_encontrado !==FALSE) {
					$resultado[] = array(
						'idtexto' => $articulo->idtexto,
						'titulo' => $articulo->titulo,
						'contenido' => '<b>'.$articulo->titulo.', '.$codigos[$articulo->idcodigo].' ('.$estados[$articulo->estado].')</b><br>'.PHP_EOL.$parrafo
					);
				}
			}

		}

		echo json_encode($resultado);
	}

	function filtro_por_parrafos($titulo, $contenido){
		

		foreach ($parrafos as $key => $parrafo) {
			// if (strlen(trim($linea)) < 1){
			// 	unset($lineas[$key]);
			// }
		}

	}

	public function modifica_form(){
		echo $this->contenido_model->modifica_informacion();
	}

	function get_texto(){
		$id = $this->input->post('id');
		$query = $this->contenido_model->get_texto_from_db($id);

		$texto = $query->result_array();

		echo json_encode($texto);
	}
	
	/*********************************************************************************

							Funciones de Consultas y casos

	*********************************************************************************/

	public function leer_consulta()
	{
		$idconsulta = $this->input->post('idconsulta');
		echo json_encode($this->consultas_model->consulta($idconsulta));
	}

	public function leer_caso()
	{
		$idcaso = $this->input->post('idcaso');
		echo json_encode($this->consultas_model->caso($idcaso));
	}

	public function nueva_consulta()
	{
		echo json_encode($this->consultas_model->nueva_consulta());
	}

	public function terminar_consulta()
	{
		$idconsulta = $this->input->post('idconsulta');
		echo json_encode($this->consultas_model->terminar_consulta($idconsulta));
	}

	public function consultas_de_caso()
	{
		$idcaso = $this->input->post('idcaso');

		$consultas = $this->consultas_model->consultas_de_caso($idcaso);
		$categorias = $this->contenido_model->get_categorias_array();

		$materias = $categorias['materias'];
		$temas = $categorias['temas'];
		$subtemas = $categorias['subtemas'];

		$json_array = array();

		foreach ($consultas as $consulta) {
			$json_array[] = array(
				'idconsulta' => $consulta->idconsulta,
				'contenido' => $consulta->contenido,
				'fecha' => $consulta->fecha,
				'materia' => $materias[$consulta->materia],
				'tema' => $temas[$consulta->tema],
				'subtema' => $subtemas[$consulta->subtema]
			);
		}

		echo json_encode($json_array);
	}

	public function nuevo_caso()
	{
		$idabogado = $this->session->userdata('consultor_idabogado');
		$caso = array(
			// 'idcaso' => 	$this->input->post('idcaso'),
			'idcliente' => 	$this->input->post('idcliente'),
			'idabogado' => 	$idabogado,
			'expedientelegal' => $this->input->post('expedientelegal'),
			'fechaapertura' => $this->input->post('fechaapertura'),
			'sinopsis' => 	$this->input->post('sinopsis'));

		echo json_encode($this->consultas_model->nuevo_caso($caso));
	}

	public function responder_consulta()
	{
		$idconsulta = $this->input->post('idconsulta');
		$respuesta = $this->input->post('respuesta');

		echo json_encode($this->consultas_model->responder_consulta($idconsulta, $respuesta));
	}

	public function guardar_consulta()
	{
		echo json_encode($this->consultas_model->guardar_consulta());
	}

	public function guardar_caso()
	{
		echo json_encode($this->consultas_model->guardar_caso());
	}

	public function lista_casos()
	{
		echo json_encode($this->consultas_model->lista_casos(''));
	}

	public function lista_casos_cliente()
	{
		$idcliente = $this->input->post('idcliente');
		echo json_encode($this->consultas_model->lista_casos($idcliente));
	}

	/*********************************************************************************

								Funciones de admin

	*********************************************************************************/



	/*********************************************************************************

								Funciones misceláneas

	*********************************************************************************/

	function get_combo_data(){
		$categorias = $this->contenido_model->leer_categorias(TRUE);
		$id = trim($this->input->post('id'));
		$tipo = trim($this->input->post('tipo'));

		$combo_data = array();

		$subcat = $categorias[$tipo];
		foreach ($subcat as $item) {
			if(isset($item['idparent']))
				if($item['idparent'] != $id)
					continue;

				$combo_data[] = array(
					'id' => $item['id'],
					'nombre' => $this->mb_ucfirst($item['nombre'])
					);
			}
			header('Content-Type: application/json', true);
			echo json_encode($combo_data);
		}

	function load_header($active_tab = 'inicio', $data = array(), $active_page = 'Acceso'){

		switch ($active_tab) {
			case 'inicio':
			$data['tab_inicio'] = TRUE;
			break;
			case 'consultas':
			$data['tab_consultas'] = TRUE;
			break;
			case 'contenido':
			$data['tab_contenido'] = TRUE;
			break;
			case 'clientes':
			$data['tab_clientes'] = TRUE;
			break;
			case 'expediente':
			$data['tab_expediente'] = TRUE;
			break;
			case 'login':
			$data['tab_login'] = TRUE;
			break;
			case 'citas':
			$data['tab_citas'] = TRUE;
			break;
		}

		$data['active_page'] = $active_page;
		$this->load->view('templates/header', $data);
	}

	function pagination_config(){
		$config['full_tag_open'] = '<ul class="pagination">';
		$config['full_tag_close'] = '</ul>';
		$config['first_link'] = false;
		$config['last_link'] = false;
		$config['first_tag_open'] = '<li>';
		$config['first_tag_close'] = '</li>';
		$config['prev_link'] = '&laquo';
		$config['prev_tag_open'] = '<li class="prev">';
		$config['prev_tag_close'] = '</li>';
		$config['next_link'] = '&raquo';
		$config['next_tag_open'] = '<li>';
		$config['next_tag_close'] = '</li>';
		$config['last_tag_open'] = '<li>';
		$config['last_tag_close'] = '</li>';
		$config['cur_tag_open'] = '<li class="active"><a href="#">';
		$config['cur_tag_close'] = '</a></li>';
		$config['num_tag_open'] = '<li>';
		$config['num_tag_close'] = '</li>';

		return $config;
	}

	// First letter uppercase
	function mb_ucfirst($str, $to_lower = false, $charset = 'utf-8')
	{
		$first = mb_strtoupper(mb_substr($str, 0, 1, $charset), $charset);
		$end = mb_substr($str, 1, mb_strlen($str, $charset), $charset);
		// Convert them all to lowercase (if specified)
		if ( $to_lower ) {
			$end = mb_strtolower($end, $charset);
		}
		return $first . $end;
	}

	// First letter lowercase
	function mb_lcfirst($str, $charset = 'utf-8'){
		$first = mb_strtolower(mb_substr($str, 0, 1, $charset), $charset);
		return $first . mb_substr($str, 1, mb_strlen($str, $charset), $charset);
	}

	function is_null_or_empty_string($question){
    	return (!isset($question) || trim($question)==='' || trim($question)==='empty');
	}
}

/* End of file usuarios_controller.php */
/* Location: ./application/controllers/usuarios_controller.php */