<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Consultas_model extends CI_Model {



	public function __construct()
	{
		parent::__construct();
		$this->load->database();
		$this->load->library('session');
		$this->load->driver('cache', array('adapter' => 'file', 'key_prefix' => 'ata_'));

		$this->idabogado = $this->session->userdata('consultor_idabogado');
	}

	public function lista_casos($idcliente = '', $order_by = 'por-fecha', $order_mode = 'asc', $start = 0, $limit=5)
	{
		$this->db->select('lista_clientes.nombres, lista_clientes.apellidop, lista_clientes.apellidom, casos.*');
		$this->db->from('casos');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('idabogado', $this->idabogado);

		if ($idcliente !== '') {
			$this->db->where('casos.idcliente', $idcliente);
		}

		//$this->db->order_by('estado', 'desc');

		if ($order_by == 'por-nombre') {
			$this->db->order_by('concat(apellidop, apellidom, nombres)', $order_mode, FALSE);
		} elseif ($order_by == 'por-fecha') {
			$this->db->order_by('fechaapertura', $order_mode);
		} 

		$this->db->limit($limit, $start);

		$query = $this->db->get();

		return $query->result();
	}

	public function lista_consultas_count()
	{
		$this->db->select('consultas.*, casos.sinopsis, lista_clientes.idcliente, lista_clientes.nombres');
		$this->db->from('consultas');
		$this->db->join('casos', 'consultas.idcaso = casos.idcaso', 'left');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('casos.idabogado', $this->idabogado);
		$this->db->where('consultas.completada', 0);

		$query = $this->db->get();

		return $query->num_rows();
	}

	public function lista_casos_count()
	{
		$this->db->select('lista_clientes.nombres, lista_clientes.apellidop, lista_clientes.apellidom, casos.*');
		$this->db->from('casos');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('idabogado', $this->idabogado);

		$query = $this->db->get();

		return $query->num_rows();
	}

	public function lista_consultas($start = 0, $limit=5, $order_by = 'por-fecha', $order_mode = 'asc')
	{
		// SELECT 
		//		consultas.*,
		//		casos.sinopsis,
		//		lista_clientes.idcliente,
		// 		lista_clientes.nombres
		// FROM
  		// 		ata.consultas
  		// LEFT JOIN
  		// 		ata.casos ON consultas.idcaso = casos.idcaso
  		// LEFT JOIN
  		// 		lista_clientes ON casos.idcliente = lista_clientes.idcliente;

		$this->db->select('consultas.*, casos.sinopsis, lista_clientes.idcliente, lista_clientes.nombres');
		$this->db->from('consultas');
		$this->db->join('casos', 'consultas.idcaso = casos.idcaso', 'left');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('casos.idabogado', $this->idabogado);
		$this->db->where('consultas.completada', 0);

		if ($order_by == 'por-nombre') {
			$this->db->order_by('concat(apellidop, apellidom, nombres)', $order_mode, FALSE);
		} elseif ($order_by == 'por-fecha') {
			$this->db->order_by('fecha', $order_mode);
		} 

		$this->db->limit($limit, $start);

		$query = $this->db->get();

		return $query->result();
	}

	public function nuevo_caso($caso=array())
	{
		$this->db->insert('casos', $caso);
	}

	public function nueva_consulta()
	{

		$consulta = array(
			// 'idconsulta' => $this->input->post('idconsulta'),
			'idcaso' => 	$this->input->post('caso'),
			'idabogado' => 	$this->idabogado,
			'fecha' => 		$this->input->post('fecha'),
			'contenido' => 	$this->input->post('contenido'),
			'materia' => 	$this->input->post('materia'),
			'tema' => 	$this->input->post('tema'),
			'subtema' => 	$this->input->post('subtema'),
			'respuesta' => 	'');

		return	$this->db->insert('consultas', $consulta);
	}

	public function guardar_consulta()
	{
		$consulta = array(
			'idconsulta' => $this->input->post('idconsulta'),
			'idcaso' => 	$this->input->post('idcaso'),
			'idabogado' => 	$this->input->post('idabogado'),
			'fecha' => 		$this->input->post('fecha'),
			'contenido' => 	$this->input->post('contenido'),
			'respuesta' => 	$this->input->post('respuesta'),
			'completada' => $this->input->post('completada'));

		$this->db->where('idconsulta', $consulta->iconsulta);
		$this->db->where('idcaso', $consulta->idcaso);

		return $this->db->update('consultas', $consulta);
	}

	public function responder_consulta($idconsulta='', $respuesta=''){
		$this->db->where('idconsulta', $idconsulta);
		
		return $this->db->update('consultas', array('respuesta' => $respuesta));
	}

	public function guardar_caso()
	{
		$caso = array(
			'idcaso' => 	$this->input->post('idcaso'),
			'idcliente' => 	$this->input->post('idcliente'),
			'idabogado' => 	$this->idabogado,
			'expedientelegal' => $this->input->post('expedientelegal'),
			'fechaapertura' => $this->input->post('fechaapertura'),
			'sinopsis' => 	$this->input->post('sinopsis'),
			'pagado' => 	$this->input->post('pagado'),
			'estado' => 	$this->input->post('estado'));

		$this->db->where('idcaso', $caso['idcaso']);
		$this->db->where('idcliente', $caso['idcliente']);

		return $this->db->update('casos', $caso);
	}

	public function terminar_consulta($idconsulta=''){
		$this->db->where('idconsulta', $idconsulta);
		return $this->db->update('consultas', array('completada' => 1));
	}

	public function consultas_de_caso($idcaso = '')
	{
		$this->db->from('consultas');
		$this->db->where('idcaso', $idcaso);
		$this->db->order_by('fecha', 'desc');

		$query = $this->db->get();

		return $query->result();
	}

	public function consulta($idconsulta = ''){
		//$this->db->select('consultas.*, casos.sinopsis, lista_clientes.idcliente, lista_clientes.nombres');
		$this->db->from('consultas');
		$this->db->join('casos', 'consultas.idcaso = casos.idcaso', 'left');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('consultas.idconsulta', $idconsulta);

		$query = $this->db->get();

		return $query->result();
	}

	public function caso($idcaso='')
	{

		$this->db->select('lista_clientes.nombres, lista_clientes.apellidop, lista_clientes.apellidom, casos.*');
		$this->db->from('casos');
		$this->db->join('lista_clientes', 'casos.idcliente = lista_clientes.idcliente', 'left');
		$this->db->where('idabogado', $this->idabogado);
		
		$this->db->where('idcaso', $idcaso);

		$this->db->order_by('fechaapertura', 'desc');
		$this->db->order_by('estado', 'desc');

		$query = $this->db->get();

		return $query->result();
	}

}

/* End of file Consultas_model */
/* Location: ./application/models/Consultas_model */